##  Assigning and Removing Tags from Fact Sheets
To assign tags to the fact sheet, follow these steps:
  1. In the fact sheet header, click Edit tags.
  2. From the drop-down list, select the tag you wish to assign from the tag group.
  3. Click Save.


If on-the-fly tagging is active, you can create new tags that aren’t in the drop-down list. To create and assign tags on the fly, do the following:
  1. In the fact sheet header, click Edit tags.
  2. Type the name of the new tag.
  3. In the drop-down, click New against the tag name.
  4. Click Save.


To remove a tag, click the 'x' on the tag after selecting Edit tags.
**Note**
Tags created on the fly do not belong to any predefined tag group and by default they are categorized under the tag group Other tags. They can be assigned to tag groups by admins. To learn more, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").
However, if you need to add or remove tags for multiple fact sheets, the most efficient way is to filter the fact sheets in the inventory and either update the data across multiple fact sheets in table view or by exporting fact sheet data as an Excel file, making the update in the spreadsheet, and importing it back. To learn more, see [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently.") and [Bulk Updating Data Through an Excel File](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD#loioc61816d6a4da4c5fbc9bc6365f2646c2__bulk_updating_data_through_excel_file).
